@@ -131,58 +131,6 @@ getctitle(Window w) {
 	return NULL;
 }
 
-void
-gravitate(Client *c, Bool invert) {
-	int dx = 0, dy = 0;
-
-	switch(c->grav) {
-	default:
-		break;
-	case StaticGravity:
-	case NorthWestGravity:
-	case NorthGravity:
-	case NorthEastGravity:
-		dy = c->border;
-		break;
-	case EastGravity:
-	case CenterGravity:
-	case WestGravity:
-		dy = -(c->h / 2) + c->border;
-		break;
-	case SouthEastGravity:
-	case SouthGravity:
-	case SouthWestGravity:
-		dy = -(c->h);
-		break;
-	}
-	switch (c->grav) {
-	default:
-		break;
-	case StaticGravity:
-	case NorthWestGravity:
-	case WestGravity:
-	case SouthWestGravity:
-		dx = c->border;
-		break;
-	case NorthGravity:
-	case CenterGravity:
-	case SouthGravity:
-		dx = -(c->w / 2) + c->border;
-		break;
-	case NorthEastGravity:
-	case EastGravity:
-	case SouthEastGravity:
-		dx = -(c->w + c->border);
-		break;
-	}
-	if(invert) {
-		dx = -dx;
-		dy = -dy;
-	}
-	c->x += dx;
-	c->y += dy;
-}
-
 void
 killclient(Arg *arg) {
 	if(!sel)
@@ -341,10 +289,6 @@ updatesize(Client *c) {
 		c->minw = c->minh = 0;
 	c->isfixed = (c->maxw && c->minw && c->maxh && c->minh &&
 				c->maxw == c->minw && c->maxh == c->minh);
-	if(c->flags & PWinGravity)
-		c->grav = size.win_gravity;
-	else
-		c->grav = NorthWestGravity;
 }
 
 void
@@ -361,12 +305,12 @@ updatetitle(Client *c) {
 	if(!name.nitems)
 		return;
 	if(name.encoding == XA_STRING)
-		strncpy(c->name, (char *)name.value, sizeof(c->name));
+		strncpy(c->name, (char *)name.value, sizeof c->name);
 	else {
 		if(XmbTextPropertyToTextList(dpy, &name, &list, &n) >= Success
 				&& n > 0 && *list)
 		{
-			strncpy(c->name, *list, sizeof(c->name));
+			strncpy(c->name, *list, sizeof c->name);
 			XFreeStringList(list);
 		}
 	}
